@@ -11,13 +11,14 @@ def get_accounts(num_processes: int, accounts_file_path: str, accounts_section:
     :param accounts_section:
     :return:
     """
+
     # try to read the accounts file and create parser
     data = configparser.ConfigParser()
     accounts_data = None
     if os.path.isfile(accounts_file_path):
         data.read(accounts_file_path)
     else:
-        print(f'Cannot find this file: <{accounts_file_path}>')
+        print(f'Cannot find this file: <{accounts_file_path}>\nExiting without running tests!')
         sys.exit(1)
 
     # get the accounts from the parser
@@ -25,6 +26,7 @@ def get_accounts(num_processes: int, accounts_file_path: str, accounts_section:
         accounts_data = data[accounts_section]
     except KeyError:
         print(f'Could not find this section: <{accounts_section}>')
+        sys.exit(1)
 
     # return a list of the accounts, if possible
     if num_processes > len(list(accounts_data.values())):
